# from jetline.pipeline.pipeline import Pipeline
# from jetline.pipeline.node import Node
# from __PIPE__ import nodes as func
#
#
# def register(data_manager) -> Pipeline:
#     return Pipeline(
#         nodes=[
#             Node(
#                 function=func.node_function_1,
#                 inputs=["Name"],
#                 outputs=["Name"],
#                 viz={"y": 150, "x": 0, "sources": ['Name']}
#             ),
#         ],
#         data_manager=data_manager)
